Image

Struct Image 

pub struct Image {
    pub obj: usize,
    pub width: Px,
    pub height: Px,
}
PDF image - obj id, width and height

Fields

obj: usize

PDF obj id

width: Px

Width

height: Px

Height

Implementations

Source

impl Image

pub fn new(s: &ImageSpec<'_>, w: &mut BasicPdfWriter) -> Image

Writes the specified image attributes and data to the PDF, returns Image with obj id, width and height.

pub fn draw(&self, page: &mut Page, x: f32, y: f32, scale: f32)

Draw image on page.