Image

Struct Image 

pub struct Image<'a> {
    pub obj: usize,
    pub data: &'a [u8],
    pub width: usize,
    pub height: usize,
    pub bits_per_component: u8,
    pub color_space: &'a [u8],
    pub other: &'a [u8],
}
PDF image - byte data and attributes that describe how image is encoded.

Fields

obj: usize

obj id

data: &'a [u8]

Image data - size is width * height * (bits_per_component/8) * 3 (for RGB).

width: usize

Width

height: usize

Height

bits_per_component: u8

Bits per component, usually 8

color_space: &'a [u8]

Color space, such as b“/DeviceGray“, b“/DeviceRGB“, b“/DeviceCMYK“

other: &'a [u8]

Any other attributes, e.g. b“/Filter/DCT“ for a jpeg

Implementations

Source

impl<'a> Image<'a>

pub fn init(&mut self, w: &mut BasicPdfWriter)

Set the obj number, write the image attributes and data to the PDF.

pub fn draw(&self, page: &mut Page, x: f32, y: f32, scale: f32)

Draw image on page.